import datetime
import typing

import kubernetes.client

class V1alpha1CSIStorageCapacity:
    api_version: typing.Optional[str]
    capacity: typing.Optional[str]
    kind: typing.Optional[str]
    maximum_volume_size: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    node_topology: typing.Optional[kubernetes.client.V1LabelSelector]
    storage_class_name: str
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        capacity: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        maximum_volume_size: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        node_topology: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        storage_class_name: str
    ) -> None: ...
    def to_dict(self) -> V1alpha1CSIStorageCapacityDict: ...

class V1alpha1CSIStorageCapacityDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    capacity: typing.Optional[str]
    kind: typing.Optional[str]
    maximumVolumeSize: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    nodeTopology: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    storageClassName: str



import datetime
import typing

import kubernetes.client

class V1beta1CertificateSigningRequestCondition:
    last_transition_time: typing.Optional[datetime.datetime]
    last_update_time: typing.Optional[datetime.datetime]
    message: typing.Optional[str]
    reason: typing.Optional[str]
    status: typing.Optional[str]
    type: str
    def __init__(
        self,
        *,
        last_transition_time: typing.Optional[datetime.datetime] = ...,
        last_update_time: typing.Optional[datetime.datetime] = ...,
        message: typing.Optional[str] = ...,
        reason: typing.Optional[str] = ...,
        status: typing.Optional[str] = ...,
        type: str
    ) -> None: ...
    def to_dict(self) -> V1beta1CertificateSigningRequestConditionDict: ...

class V1beta1CertificateSigningRequestConditionDict(typing.TypedDict, total=False):
    lastTransitionTime: typing.Optional[datetime.datetime]
    lastUpdateTime: typing.Optional[datetime.datetime]
    message: typing.Optional[str]
    reason: typing.Optional[str]
    status: typing.Optional[str]
    type: str



import datetime
import typing

import kubernetes.client

class V1EndpointHints:
    for_zones: typing.Optional[list[kubernetes.client.V1ForZone]]
    def __init__(
        self, *, for_zones: typing.Optional[list[kubernetes.client.V1ForZone]] = ...
    ) -> None: ...
    def to_dict(self) -> V1EndpointHintsDict: ...

class V1EndpointHintsDict(typing.TypedDict, total=False):
    forZones: typing.Optional[list[kubernetes.client.V1ForZoneDict]]



import datetime
import typing

import kubernetes.client

class V1EphemeralVolumeSource:
    volume_claim_template: typing.Optional[
        kubernetes.client.V1PersistentVolumeClaimTemplate
    ]
    def __init__(
        self,
        *,
        volume_claim_template: typing.Optional[
            kubernetes.client.V1PersistentVolumeClaimTemplate
        ] = ...
    ) -> None: ...
    def to_dict(self) -> V1EphemeralVolumeSourceDict: ...

class V1EphemeralVolumeSourceDict(typing.TypedDict, total=False):
    volumeClaimTemplate: typing.Optional[
        kubernetes.client.V1PersistentVolumeClaimTemplateDict
    ]



import datetime
import typing

import kubernetes.client

class V1beta1CronJob:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    spec: typing.Optional[kubernetes.client.V1beta1CronJobSpec]
    status: typing.Optional[kubernetes.client.V1beta1CronJobStatus]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        spec: typing.Optional[kubernetes.client.V1beta1CronJobSpec] = ...,
        status: typing.Optional[kubernetes.client.V1beta1CronJobStatus] = ...
    ) -> None: ...
    def to_dict(self) -> V1beta1CronJobDict: ...

class V1beta1CronJobDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    spec: typing.Optional[kubernetes.client.V1beta1CronJobSpecDict]
    status: typing.Optional[kubernetes.client.V1beta1CronJobStatusDict]



import datetime
import typing

import kubernetes.client

class NetworkingV1beta1IngressList:
    api_version: typing.Optional[str]
    items: list[kubernetes.client.NetworkingV1beta1Ingress]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ListMeta]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        items: list[kubernetes.client.NetworkingV1beta1Ingress],
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ListMeta] = ...
    ) -> None: ...
    def to_dict(self) -> NetworkingV1beta1IngressListDict: ...

class NetworkingV1beta1IngressListDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    items: list[kubernetes.client.NetworkingV1beta1IngressDict]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ListMetaDict]
